/*
 * DHPrivateKey.java
 *
 * This class is part of our JCE 1.2 provider
 *
 * Copyright (c) 1999-2000 Virtual Unlimited B.V.
 *
 * Author: Bob Deblier <bob@virtualunlimited.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package com.beeyond.crypto;

import java.math.BigInteger;
import javax.crypto.spec.DHParameterSpec;

/**
 * This class implements a Diffie-Hellman private key.
 * <p>
 * @author Bob Deblier &lt;bob@virtualunlimited.com&gt;
 */
public class DHPrivateKey extends DHKey implements javax.crypto.interfaces.DHPrivateKey
{
	private BigInteger x;

	public DHPrivateKey(DHParameterSpec params, BigInteger x)
	{
		super(params);
		this.x = x;
	}

	public DHPrivateKey(BigInteger p, BigInteger g, BigInteger x)
	{
		super(p, g);
		this.x = x;
	}

	public BigInteger getX()
	{
		return x;
	}

	public String toString()
	{
		return super.toString() + "\nX=" + getX().toString(16);
	}
}
